@@ -134,7 +134,7 @@ class Customer(Resource):
         return Configuration.gateway().customer.delete(customer_id)
 
     @staticmethod
-    def find(customer_id):
+    def find(customer_id, association_filter_id=None):
         """
         Find an customer, given a customer_id.  This does not return a result
         object.  This will raise a :class:`NotFoundError <braintree.exceptions.not_found_error.NotFoundError>` if the provided customer_id
@@ -143,7 +143,7 @@ class Customer(Resource):
             customer = braintree.Customer.find("my_customer_id")
         """
 
-        return Configuration.gateway().customer.find(customer_id)
+        return Configuration.gateway().customer.find(customer_id, association_filter_id)
 
     @staticmethod
     def search(*query):
@@ -203,6 +203,7 @@ class Customer(Resource):
                 "custom_field",
                 "description",
                 "amount",
+                { "shipping": Address.create_signature() }
             ]}]},
         ]
 
@@ -211,7 +212,15 @@ class Customer(Resource):
         return [
             "company", "email", "fax", "first_name", "id", "last_name", "phone", "website", "device_data", "device_session_id", "fraud_merchant_id", "payment_method_nonce", "default_payment_method_token",
             {"credit_card": CreditCard.signature("update_via_customer")},
-            {"custom_fields": ["__any_key__"]}
+            {"custom_fields": ["__any_key__"]},
+            {"options": [{"paypal": [
+                "payee_email",
+                "order_id",
+                "custom_field",
+                "description",
+                "amount",
+                { "shipping": Address.create_signature() }
+            ]}]},
         ]
 
     def __init__(self, gateway, attributes):
